@@ -1,8 +1,9 @@
 #![doc = include_str!("../Readme.md")]
-#![feature(trait_alias)]
 
 mod json;
 mod methods;
 
 pub use methods::*;
-pub use serde_json::Map;
+pub use serde_json::{Map, Value as Json};
+
+pub type JsonObject = Map<String, Json>;
